@@ -7,6 +7,7 @@ package W3C::SOAP::WADL::Document;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit::Root;
 use version;
 use Carp;
@@ -14,7 +15,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use W3C::SOAP::WADL::Document::Resources;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 add_xpath_namespace wadl => 'http://wadl.dev.java.net/2009/02';
 add_xpath_namespace json => 'http://rest.domain.gdl.optus.com.au/rest/3/common-json';
@@ -40,6 +41,9 @@ has_xpath_object_list representation => (
 has_xpath_object_list param => (
     '//wadl:param' => 'W3C::SOAP::WADL::Document::Param',
 );
+has_xpath_object_list schemas => (
+    '//wadl:grammars/wadl:include' => 'W3C::SOAP::WADL::XSD',
+);
 
 has module => (
     is        => 'rw',
@@ -56,6 +60,13 @@ has file => (
     isa       => 'Str',
     predicate => 'has_file',
 );
+has ns_module_map => (
+    is        => 'rw',
+    isa       => 'HashRef[Str]',
+    required  => 1,
+    predicate => 'has_ns_module_map',
+    default   => sub{{}},
+);
 
 finalize_class();
 
@@ -69,7 +80,7 @@ W3C::SOAP::WADL::Document - The representation of the WADL document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document version 0.005.
 
 =head1 SYNOPSIS
 
