@@ -7,14 +7,14 @@ package W3C::SOAP::WADL::Document::Doc;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use W3C::SOAP::WADL::Document::Param;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value lang => './@xml:lang';
 has_xpath_value title => './@title';
@@ -28,11 +28,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Doc - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Doc - Container for WADL doc element
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Doc version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Doc version 0.005.
 
 =head1 SYNOPSIS
 
