@@ -7,6 +7,7 @@ package W3C::SOAP::WADL::Document::Method;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
@@ -15,7 +16,7 @@ use English qw/ -no_match_vars /;
 use W3C::SOAP::WADL::Document::Request;
 use W3C::SOAP::WADL::Document::Response;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value name => './@name';
 has_xpath_value id   => './@id';
@@ -37,11 +38,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Method - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Method - Container for WADL method elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Method version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Method version 0.005.
 
 =head1 SYNOPSIS
 
