@@ -7,6 +7,7 @@ package W3C::SOAP::WADL::Document::Option;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
@@ -14,7 +15,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use W3C::SOAP::WADL::Document::Param;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_object_list param => (
     './wadl:param' => 'W3C::SOAP::WADL::Document::Param',
@@ -29,11 +30,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Option - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Option - Container for WADL option elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Option version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Option version 0.005.
 
 =head1 SYNOPSIS
 
