@@ -7,13 +7,14 @@ package W3C::SOAP::WADL::Document::Param;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value id => './@id';
 has_xpath_value name => './@name';
@@ -33,11 +34,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Param - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Param - Container for WADL param elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Param version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Param version 0.005.
 
 =head1 SYNOPSIS
 
