@@ -7,6 +7,7 @@ package W3C::SOAP::WADL::Document::Representation;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
@@ -14,7 +15,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use W3C::SOAP::WADL::Document::Param;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value id         => './@id';
 has_xpath_value media_type => './@mediaType';
@@ -35,11 +36,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Representation - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Representation - Container for WADL representation elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Representation version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Representation version 0.005.
 
 =head1 SYNOPSIS
 
