@@ -7,14 +7,17 @@ package W3C::SOAP::WADL::Document::Resource;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
+use W3C::SOAP::WADL::Document::Param;
 use W3C::SOAP::WADL::Document::Method;
+use W3C::SOAP::WADL::Document::Resource;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value id        => './@id';
 has_xpath_value path      => './@path';
@@ -41,11 +44,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Resource - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Resource - Container for WADL resource elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Resource version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Resource version 0.005.
 
 =head1 SYNOPSIS
 
