@@ -7,14 +7,16 @@ package W3C::SOAP::WADL::Document::Response;
 # $Revision$, $Source$, $Date$
 
 use strict;
+use warnings;
 use XML::Rabbit;
 use version;
 use Carp;
 use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use W3C::SOAP::WADL::Document::Param;
+use W3C::SOAP::WADL::Document::Representation;
 
-our $VERSION     = version->new('0.004');
+our $VERSION = version->new('0.005');
 
 has_xpath_value status => './@status';
 
@@ -36,11 +38,11 @@ __END__
 
 =head1 NAME
 
-W3C::SOAP::WADL::Document::Response - <One-line description of module's purpose>
+W3C::SOAP::WADL::Document::Response - Container for WADL response elements
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WADL::Document::Response version 0.1.
+This documentation refers to W3C::SOAP::WADL::Document::Response version 0.005.
 
 =head1 SYNOPSIS
 
